
# Sequenzo: Fast, scalable, and intuitive social sequence analysis

Sequenzo is a high-performance Python package designed for social sequence analysis. It is built to analyze **any sequence of categorical events**, from individual career paths and migration patterns to corporate growth and urban development. 
Whether you are working with **people, places, or policies**, Sequenzo helps uncover meaningful patterns efficiently. 

Sequenzo outperforms traditional R-based tools in social sequence analysis, delivering faster processing and superior efficiency, especially for large-scale datasets. **No big data? No problem. You don’t need big data to benefit as Sequenzo is designed to enhance sequence analysis at any scale, making complex methods accessible to everyone.**

## Why Choose Sequenzo?

🚀 **High Performance**

Leverages Python’s computational power to achieve 10× faster processing than traditional R-based tools like TraMineR.

🎯 **Easy-to-Use API**

Designed with simplicity in mind: intuitive functions streamline complex sequence analysis without compromising flexibility.

🌍 **Flexible for Any Scenario**

Perfect for research, policy, and business, enabling seamless analysis of categorical data and its evolution over time.

## Documentation

Explore the full Sequenzo documentation [here](sequenzo.yuqi-liang.tech).

**Where to start on the documentation website?**
* New to Sequenzo or social sequence analysis? Begin with "About Sequenzo" → "Quickstart Guide" for a smooth introduction.
* Got your own data? After going through "About Sequenzo" and "Quickstart Guide", you are ready to dive in and start analyzing.
* Looking for more? Check out our example datasets and tutorials to deepen your understanding.

For Chinese users, additional tutorials are available on [Yuqi's video tutorials on Bilibili](https://space.bilibili.com/263594713/lists/4147974).

## Installation

The latest stable release and required dependencies can be installed from PyPI. You can type the following line in your terminal:

```
pip install sequenzo
```

## Join the Community

💬 **Have a question or found a bug?**

Please submit an issue on [GitHub Issues](https://github.com/Liang-Team/Sequenzo/issues). 

For an effective bug report, please include the following:
* A reproducible code example that clearly demonstrates the issue.
* The output you’re seeing, such as an error message or an image of the plot.
* A brief explanation of why you believe this is a bug.

Providing these details will help us diagnose and resolve the issue more efficiently. We are always happy to help and will address it as soon as possible.

🌟 **Enjoying Sequenzo?**

Support the project by starring ⭐ the GitHub repo and spreading the word!

🛠 **Interested in contributing?**

Check out our [contribution guide]() for more details. 

* Write code? Submit a pull request to enhance Sequenzo.
* Testing? Try Sequenzo and share your feedback. Every suggestion counts!

## Team

**Authors**
* Yuqi Liang, University of Oxford
* Xinyi Li, Heilongjiang University
* Jan Heinrich Ernst Meyerhoff-Liang, Institute for New Economic Thinking Oxford

**Ackowledgements**
* Technical advisor in sequence analysis: Tim Liao, University of Illinois Urbana-Champaign
* Website and related technical support: Mactavish
* Logo and color design: Changyu Yi
* Sequence data sources compilation
  * Economics: Jan Meyerhoff-Liang
  * History: Jingrui Chen
  * Public health: Yuelu Yin
* Testing
